@@ -1,5 +1,5 @@
 from paste.auth import grantip
-from paste.fixture import *
+from paste.fixture import TestApp
 
 def _make_app():
     def application(environ, start_response):
@@ -9,8 +9,7 @@ def _make_app():
             ':',
             str(environ.get('REMOTE_USER_TOKENS')),
             ]
-        if six.PY3:
-            lines = [line.encode('utf8') for line in lines]
+        lines = [line.encode('utf8') for line in lines]
         return lines
     ip_map = {
         '127.0.0.1': (None, 'system'),
