@@ -1,6 +1,6 @@
-import six
+import io
 
-from paste.request import *
+from paste.request import parse_formvars, parse_querystring
 from paste.util.multidict import MultiDict
 
 def test_parse_querystring():
@@ -18,7 +18,7 @@ def make_post(body):
         'CONTENT_TYPE': 'application/x-www-form-urlencoded',
         'CONTENT_LENGTH': str(len(body)),
         'REQUEST_METHOD': 'POST',
-        'wsgi.input': six.BytesIO(body),
+        'wsgi.input': io.BytesIO(body),
         }
     return e
 
